@@ -37,6 +37,28 @@ class WeightedModels:
     def models(self):
         return self.__models
 
+    @property
+    def feature_importances_(self):
+        if not self.__weights:
+            raise Exception("Models are not fitted yet. Use .fit() before calling .feature_importances_")
+
+        importances = []
+        
+        for model in self.__models:
+            try:
+                imprt = list(map(lambda x: x/sum(model.feature_importances_) ,model.feature_importances_))
+                importances.append(imprt)
+            except AttributeError:
+                imprt = list(map(lambda x: x/sum(model.coef_) ,model.coef_))
+                importances.append(imprt)
+
+        weightedImpotances = []
+
+        for i in range(len(importances)):
+            weightedImpotances.append(list(map(lambda x: x * self.__weights[i], importances[i])))
+            
+        return [sum(x) for x in zip(*weightedImpotances)]
+
     @property
     def modelWeights(self):
         if not self.__weights:
@@ -44,11 +66,14 @@ class WeightedModels:
         
         return self.__weights
             
-    def fit(self, X, y, showScores = True):
+    def fit(self, X, y, X_val = None, y_val = None ,showScores = True):
         self.__X_train, self.__X_test, self.__y_train, self.__y_test = train_test_split(X, y, train_size=self.trainSplit, random_state=self.randomState)
-        
+
         for model in self.__models:
-            model.fit(self.__X_train, self.__y_train)  
+            if ('eval_set' in model.fit.__code__.co_varnames) and (X_val is not None) and (y_val is not None):
+                model.fit(self.__X_train, self.__y_train, eval_set = [(self.__X_train, self.__y_train), (X_val, y_val)])
+            else:
+                model.fit(self.__X_train, self.__y_train)
         
         self.__calculateWeights()
 
